@@ -20,6 +20,7 @@
 define('AREA', 'customer');
 require './lib/init.php';
 
+
 if (isset($_POST['id'])) {
 
 	$id = intval($_POST['id']);
@@ -92,8 +93,10 @@ if ($page == 'overview') {
 				}
 
 				$row['subject'] = html_entity_decode($row['subject']);
-				if (strlen($row['subject']) > 20) {
-					$row['subject'] = substr($row['subject'], 0, 17) . '...';
+				if (strlen($row['subject']) > 30) {
+					$ts = wordwrap($row['subject'], 30, "|");
+					$ts = explode("|", $ts);
+					$row['subject'] = $ts[0]. '...';
 				}
 
 				eval("\$tickets.=\"" . getTemplate("tickets/tickets_tickets") . "\";");
@@ -325,7 +328,7 @@ if ($page == 'overview') {
 
 				$subject = $subticket->Get('subject');
 				$message = $subticket->Get('message');
-				
+
 				$row2 = htmlentities_array($row2);
 				eval("\$ticket_replies.=\"" . getTemplate("tickets/tickets_tickets_list") . "\";");
 			}
