@@ -21,12 +21,6 @@
 
 class phpinterface {
 
-	/**
-	 * Settings array
-	 * @var array
-	 */
-	private $_settings = array();
-
 	/**
 	 * Domain-Data array
 	 * @var array
@@ -48,8 +42,7 @@ class phpinterface {
 	/**
 	 * main constructor
 	 */
-	public function __construct($settings, $domain) {
-		$this->_settings = $settings;
+	public function __construct($domain) {
 		$this->_domain = $domain;
 		$this->_setInterface();
 	}
@@ -69,11 +62,11 @@ class phpinterface {
 	 */
 	private function _setInterface() {
 		// php-fpm
-		if ((int)$this->_settings['phpfpm']['enabled'] == 1) {
-			$this->_interface = new phpinterface_fpm($this->_settings, $this->_domain);
+		if ((int)Settings::Get('phpfpm.enabled') == 1) {
+			$this->_interface = new phpinterface_fpm($this->_domain);
 
-		} elseif ((int)$this->_settings['system']['mod_fcgid'] == 1) {
-			$this->_interface = new phpinterface_fcgid($this->_settings, $this->_domain);
+		} elseif ((int)Settings::Get('system.mod_fcgid') == 1) {
+			$this->_interface = new phpinterface_fcgid($this->_domain);
 		}
 	}
 
@@ -98,6 +91,12 @@ class phpinterface {
 					SELECT * FROM `" . TABLE_PANEL_PHPCONFIGS . "` WHERE `id` = :id"
 			);
 			$this->_php_configs_cache[$php_config_id] = Database::pexecute_first($stmt, array('id' => $php_config_id));
+			if ((int)Settings::Get('phpfpm.enabled') == 1) {
+				$stmt = Database::prepare("
+					SELECT * FROM `" . TABLE_PANEL_FPMDAEMONS . "` WHERE `id` = :id"
+				);
+				$this->_php_configs_cache[$php_config_id]['fpm_settings'] = Database::pexecute_first($stmt, array('id' => $this->_php_configs_cache[$php_config_id]['fpmsettingid']));
+			}
 		}
 
 		return $this->_php_configs_cache[$php_config_id];
