@@ -214,6 +214,11 @@ return array(
 					'label' => $lng['admin']['ipsandports']['ipsandports'],
 					'required_resources' => 'change_serversettings'
 				),
+				array(
+					'url' => 'admin_plans.php?page=overview',
+					'label' => $lng['admin']['plans']['plans'],
+					'required_resources' => 'customers'
+				),
 				array(
 					'url' => 'admin_settings.php?page=updatecounters',
 					'label' => $lng['admin']['updatecounters'],
